# Geoclue Stumbler

Copyright (C) 2024, Chris Talbot

<div align="center">
  <img src="https://gitlab.com/kop316/geoclue-stumbler/-/raw/main/data/metainfo/screenshot.png?inline=false" width="200" >
  <img src="https://gitlab.com/kop316/geoclue-stumbler/-/raw/main/data/metainfo/screenshot2.png?inline=false" width="200" >
  <img src="https://gitlab.com/kop316/geoclue-stumbler/-/raw/main/data/metainfo/screenshot3.png?inline=false" width="200" >
</div>

## About
[Geoclue](https://gitlab.freedesktop.org/geoclue/geoclue) has the ability
(assuming the hardware is supported) to collect Cell tower and WiFi Access Point
(AP) location data and submit the data to an
[Ichnaea](https://ichnaea.readthedocs.io/en/latest/api/geosubmit2.html)
compatible server (e.g. [beaconDB](https://beacondb.net/)). However, geoclue only
collects/submits data if and only if a client is actively connected to geoclue.

Geoclue Stumbler is geoclue client in GTK4/Libadwaita. While running, it ensures
geoclue is active to submit cell tower/WiFi Access point data, provides the user
feedback on if geoclue can submit data.

The user also has an option to show the path of that user has been on during
active collection/submission. It will show various statistics (distance travelled,
average speed, and current speed) and gives the user the option of saving
their path as a GPX file.

## Setting up geoclue with BeaconDB

To enable BeaconDB for geoclue (to include automatic data submission), Add:

```
# https://beacondb.net & https://beacondb.net/map
[wifi]
enable=true
url=https://api.beacondb.net/v1/geolocate
# Contributing back
submit-data=true
submission-url=https://api.beacondb.net/v2/geosubmit
# I doubt this is used, but explicitly set just in case of it suddenly
# becoming $(whoami)
submission-nick=geoclue
```

to /etc/geoclue/conf.d/beacondb.conf (taken from
[here](https://gitea.blesmrt.net/mikaela/shell-things/src/branch/cxefa/etc/geoclue/conf.d/beacondb.conf)).

Please note that this [MR](https://gitlab.freedesktop.org/geoclue/geoclue/-/merge_requests/192)
is required for Geoclue to successfully upload information to BeaconDB.

## License
Unless otherwise specified, all code is licensed under the
[GPL Version 3 or later](https://www.gnu.org/licenses/gpl-3.0.en.html), and all
other images/data is licensed under  Creative Commons
Attribution-ShareAlike 4.0 International [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/).

Path Marker Logo from [GNOME Maps](https://apps.gnome.org/Maps/) and is licensed under [GPL 2+](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

Map Marker Logo from [libshumate](https://gitlab.gnome.org/GNOME/libshumate/) and is licensed under [LGPL 2.1+](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html).

### Install dependencies

On a Debian based system run

``` bash
    sudo apt-get -y install build-essential
    sudo apt-get -y build-dep .
```

For an explicit list of dependencies, check the Build-Depends entry in the
[debian/control](https://gitlab.com/kop316/gtk-meshtastic-client/-/blob/main/debian/control)
file or the .gitlab-ci.yml file.

## Build Debian Package

After installing the dependencies, simply run

``` bash
    dpkg-buildpackage -B
```

## Compiling Geoclue Stumbler
In order to compile Geoclue Stumbler you need following software packages:

- GCC compiler
- GTK4 library
- libadwaita
- libgeoclue


## Installing Geoclue Stumbler
Build tools requirements

When building and testing directly from the repository it is important to
have at least meson version 0.56 or later installed. In addition, some
supported Meson backend is required (e.g. ninja).

To prepare/configure the project for compilation:

``` bash
    meson setup _build
```

However, if you want to install it, run

``` bash
    meson setup _build -Dprefix=/usr --sysconfdir=/etc
```

`--sysconfdir=/etc` will install the autostart file in the correct place, and
`-Dprefix=/usr` installs `Geoclue Stumbler` in `/usr/bin/` rather than `/usr/local/bin`

To build the project:

``` bash
    meson compile -C _build
```

Install (may require sudo or root privileges):

``` bash
    meson install -C _build
```

Uninstall (may require sudo or root privileges):

``` bash
    ninja uninstall -C _build/
```

## Running from within the source code repository
Meson will build the binary in builddir (_build, using the examples above), and
can be invoked directly.

Run with debugging
``` bash
    ./_build/src/Geoclue Stumbler -d
```
